@@ -101,7 +101,7 @@ def json_packer(obj):
             default=json_default,
             ensure_ascii=False,
             allow_nan=False,
-        ).encode("utf8")
+        ).encode("utf8", errors="surrogateescape")
     except (TypeError, ValueError) as e:
         # Fallback to trying to clean the json before serializing
         packed = json.dumps(
@@ -109,7 +109,7 @@ def json_packer(obj):
             default=json_default,
             ensure_ascii=False,
             allow_nan=False,
-        ).encode("utf8")
+        ).encode("utf8", errors="surrogateescape")
 
         warnings.warn(
             f"Message serialization failed with:\n{e}\n"
@@ -216,7 +216,7 @@ class SessionFactory(LoggingConfigurable):
     logname = Unicode("")
 
     @observe("logname")  # type:ignore[misc]
-    def _logname_changed(self, change: Any) -> None:
+    def _logname_changed(self, change: t.Any) -> None:
         self.log = logging.getLogger(change["new"])
 
     # not configurable:
@@ -1077,7 +1077,7 @@ class Session(Configurable):
         # adapt to the current version
         return adapt(message)
 
-    def unserialize(self, *args: Any, **kwargs: Any) -> t.Dict[str, t.Any]:
+    def unserialize(self, *args: t.Any, **kwargs: t.Any) -> t.Dict[str, t.Any]:
         warnings.warn(
             "Session.unserialize is deprecated. Use Session.deserialize.",
             DeprecationWarning,
